'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

const React = require('react');
const Section = require('./section');
const { hamburgerIcon } = require('../nav-icons');

class MiddlePanel extends React.PureComponent {
  constructor(props) {
    super(props);

    this.state = {
      isMobile: this.props.isMobile,
      activeSection: this.props.activeSection
    };

    this.renderSection = this.renderSection.bind(this);
  }

  componentWillReceiveProps(newProps) {
    this.setState({
      activeSection: newProps.activeSection,
      isMobile: newProps.isMobile
    });
  }

  onTabSelect(i, e) {
    e.preventDefault();

    if (this.state.activeSection === i) {
      i = -1;
    }

    this.props.setActiveSection(i);
    this.setState({ activeSection: i });

    return false;
  }

  renderSection(section, i) {
    return React.createElement(Section, _extends({
      key: i,
      className: `nav-panel-middle__li nav-panel-middle__btn ${this.state.activeSection === i ? 'nav-panel-middle__li--active' : ''}`,
      handler: this.onTabSelect.bind(this, i)
    }, section));
  }

  render() {
    return React.createElement(
      'div',
      { className: 'nav-panel-middle' },
      React.createElement(
        'ul',
        {
          className: 'nav-panel-middle__ul flex flex--space-between flex--wrap' },
        React.createElement(
          'a',
          { href: this.props.logoLink, className: 'flex flex--center-y' },
          React.createElement(
            'li',
            { className: 'nav-panel-middle__li nav-panel-middle__logo' },
            React.createElement('img', {
              className: 'nav-panel-middle__logo-img',
              src: this.props.logoUrl })
          ),
          React.createElement(
            'li',
            { className: 'nav-panel-middle__li nav-panel-middle__tagline-container' },
            React.createElement(
              'p',
              { className: 'nav-panel-middle__tagline' },
              this.props.tagline
            )
          )
        ),
        React.createElement(
          'div',
          {
            className: 'nav-panel-middle__container flex flex--center-all flex--wrap',
            style: this.state.isMobile ? { display: 'none' } : {} },
          this.props.sections.map(this.renderSection)
        ),
        React.createElement(
          'li',
          {
            onClick: this.props.toggle,
            className: 'nav-panel-middle__hamburger' },
          React.createElement(
            'button',
            null,
            hamburgerIcon
          )
        )
      )
    );
  }
}

const { func, number, bool, string, array } = React.PropTypes;

MiddlePanel.propTypes = {
  setActiveSection: func.isRequired,
  toggle: func.isRequired,
  activeSection: number,
  isMobile: bool.isRequired,
  sections: array,
  logoUrl: string,
  logoLink: string,
  tagline: string
};

MiddlePanel.defaultProps = {
  logoLink: '/',
  tagline: 'For Giant Ideas',
  activeSection: -1
};

module.exports = MiddlePanel;