'use strict';

const React = require('react');
const SearchInput = require('./search');
const { contactIcon, downloadIcon, rocketIcon } = require('../nav-icons');

function TopPanel(props) {
  return React.createElement(
    'div',
    { className: 'nav-panel-top font--center' },
    React.createElement(
      'ul',
      { className: 'flex flex--space-between', style: { height: '100%' } },
      React.createElement(
        'div',
        { className: 'nav-panel-top__links flex flex--center-y font--center' },
        props.sections.map(renderSection)
      ),
      React.createElement(
        'div',
        { className: 'flex flex--center-y' },
        React.createElement(
          'a',
          { href: props.contactUrl },
          React.createElement(
            'button',
            {
              className: 'flex flex--center-all flex--wrap nav-panel-top__contact',
              style: props.includeSearch ? {} : { marginRight: '15px' } },
            contactIcon
          )
        ),
        props.includeSearch && React.createElement(SearchInput, { searchUrl: props.searchUrl }),
        React.createElement(
          'a',
          {
            id: 'mongodb-nav-hosting-btn',
            className: 'nav-panel-top__a',
            href: '/cloud/atlas?jmp=nav' },
          React.createElement(
            'button',
            { className: 'btn-small btn-hollow btn-hollow--light-green margin--left-xs nav-panel-top__hosting' },
            React.createElement(
              'span',
              { style: { verticalAlign: 'middle' } },
              'Free Hosting'
            ),
            rocketIcon
          )
        ),
        React.createElement(
          'a',
          {
            id: 'mongodb-nav-download-btn',
            className: 'nav-panel-top__a',
            href: `${props.host}${props.downloadUrl}${props.downloadJmpValue === '' ? '' : `?jmp=${props.downloadJmpValue}`}`,
            target: props.host === '' ? '_self' : '_blank' },
          React.createElement(
            'button',
            { className: 'btn-small btn-fill btn-fill--light-green margin--left-xs nav-panel-top__download' },
            React.createElement(
              'span',
              { style: { verticalAlign: 'middle' } },
              'Download'
            ),
            downloadIcon
          )
        )
      )
    )
  );
}

function renderSection(section, i) {
  return React.createElement(
    'a',
    {
      key: i,
      className: 'nav-panel-top__a',
      target: section.self ? '_self' : '_blank',
      href: section.href },
    React.createElement(
      'li',
      { className: 'nav-panel-top__li' },
      section.text
    )
  );
}

const { string, bool, array } = React.PropTypes;

TopPanel.propTypes = {
  includeSearch: bool,
  searchUrl: string,
  contactUrl: string,
  sections: array,
  host: string.isRequired,
  downloadUrl: string,
  downloadJmpValue: string
};

TopPanel.defaultProps = {
  includeSearch: true,
  searchUrl: '/search?search=',
  contactUrl: '/contact?jmp=nav',
  downloadUrl: '/download-center',
  downloadJmpValue: 'nav'
};

module.exports = TopPanel;