const React = require('react')
const Section = require('./section')
const { hamburgerIcon } = require('../nav-icons')

class MiddlePanel extends React.PureComponent {
  constructor (props) {
    super(props)

    this.state = {
      isMobile: this.props.isMobile,
      activeSection: this.props.activeSection
    }

    this.renderSection = this.renderSection.bind(this)
  }

  componentWillReceiveProps (newProps) {
    this.setState({
      activeSection: newProps.activeSection,
      isMobile: newProps.isMobile
    })
  }

  onTabSelect (i, e) {
    e.preventDefault()

    if (this.state.activeSection === i) {
      i = -1
    }

    this.props.setActiveSection(i)
    this.setState({ activeSection: i })

    return false
  }

  renderSection (section, i) {
    return (
      <Section
        key={i}
        className={`nav-panel-middle__li nav-panel-middle__btn ${
          this.state.activeSection === i ? 'nav-panel-middle__li--active' : ''
        }`}
        handler={this.onTabSelect.bind(this, i)}
        {...section} />
    )
  }

  render () {
    return (
      <div className='nav-panel-middle'>
        <ul
          className='nav-panel-middle__ul flex flex--space-between flex--wrap'>
          <a href={this.props.logoLink} className='flex flex--center-y'>
            <li className='nav-panel-middle__li nav-panel-middle__logo'>
              <img
                className='nav-panel-middle__logo-img'
                src={this.props.logoUrl} />
            </li>
            <li className='nav-panel-middle__li nav-panel-middle__tagline-container'>
              <p className='nav-panel-middle__tagline'>{ this.props.tagline }</p>
            </li>
          </a>
          <div
            className='nav-panel-middle__container flex flex--center-all flex--wrap'
            style={this.state.isMobile ? { display: 'none' } : {}}>
            {this.props.sections.map(this.renderSection)}
          </div>
          <li
            onClick={this.props.toggle}
            className='nav-panel-middle__hamburger'>
            <button>
              { hamburgerIcon }
            </button>
          </li>
        </ul>
      </div>
    )
  }
}

const { func, number, bool, string, array } = React.PropTypes

MiddlePanel.propTypes = {
  setActiveSection: func.isRequired,
  toggle: func.isRequired,
  activeSection: number,
  isMobile: bool.isRequired,
  sections: array,
  logoUrl: string,
  logoLink: string,
  tagline: string
}

MiddlePanel.defaultProps = {
  logoLink: '/',
  tagline: 'For Giant Ideas',
  activeSection: -1
}

module.exports = MiddlePanel
