const React = require('react')
const TopPanel = require('./components/panel-top')
const MiddlePanel = require('./components/panel-middle')
const BottomPanel = require('./components/panel-bottom')
const Background = require('./components/background')

class Nav extends React.PureComponent {
  constructor (props) {
    super(props)

    this.state = {
      isMobile: true,
      isOpen: false,
      activeSection: -1,
      breakpoint: 895
    }

    this.toggle = this.toggle.bind(this)
    this.setActiveSection = this.setActiveSection.bind(this)
    this.onResize = this.onResize.bind(this)
  }

  componentDidMount () {
    this.setState({
      isMobile: window.innerWidth <= this.state.breakpoint
    })

    window.addEventListener('resize', () => {
      if (this.rafId) return

      this.rafId = window.requestAnimationFrame(this.onResize)
    })
  }

  onResize () {
    const { isMobile, breakpoint } = this.state
    const { innerWidth } = window

    if (isMobile && innerWidth > breakpoint) {
      this.setState({ isMobile: false, isOpen: false, activeSection: -1 })
      document.body.classList.toggle('no-scroll', false)
    } else if (!isMobile && innerWidth <= breakpoint) {
      this.setState({ isMobile: true, activeSection: -1 })
    }

    this.rafId = undefined
  }

  setActiveSection (activeSection) {
    this.setState({ activeSection })
  }

  toggle (isOpen) {
    isOpen = isOpen || !this.state.isOpen

    if (this.state.isMobile) {
      document.body.classList.toggle('no-scroll', isOpen)
    }

    this.setState({ isOpen })
  }

  render () {
    const { isOpen, activeSection } = this.state

    return (
      <nav className='nav-panel flex flex--center-y flex--wrap'>
        <TopPanel
          downloadUrl={this.props.downloadUrl}
          downloadJmpValue={this.props.downloadJmpValue}
          includeSearch={this.props.includeSearch}
          host={this.props.environment === 'com' ? '' : 'https://www.mongodb.com'}
          sections={this.props.topSections}
          searchUrl={this.props.searchUrl}
          contactUrl={this.props.contactUrl} />
        <MiddlePanel
          activeSection={this.state.activeSection}
          isMobile={this.state.isMobile}
          logoUrl={this.props.logoUrl}
          tagline={this.props.tagline}
          logoLink={this.props.logoLink}
          sections={this.props.sections}
          toggle={this.toggle}
          setActiveSection={this.setActiveSection} />
        <Background
          isMobile={this.state.isMobile}
          setActiveSection={this.setActiveSection}
          isOpaque={isOpen || activeSection !== -1 || this.props.isOpaque}
          isOpen={isOpen || activeSection !== -1}>
          <BottomPanel
            isMobile={this.state.isMobile}
            activeSection={this.state.activeSection}
            midSections={this.props.sections}
            sections={this.props.subsections} />
        </Background>
      </nav>
    )
  }
}

const { bool, string, array } = React.PropTypes

Nav.propTypes = {
  topSections: array,
  sections: array,
  subsections: array,

  isOpaque: bool,
  includeSearch: bool,

  environment: string,
  searchUrl: string,
  contactUrl: string,
  downloadUrl: string,
  downloadJmpValue: string,
  logoUrl: string,
  logoLink: string,
  tagline: string
}

Nav.defaultProps = {
  environment: 'com'
}

module.exports = Nav
